==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/SecurityContactPropertiesNotificationsByRoleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.SecurityContactPropertiesNotificationsByRoleArgs.builder
import com.pulumi.azurenative.security.kotlin.enums.Roles
import com.pulumi.azurenative.security.kotlin.enums.State
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines whether to send email notifications from Microsoft Defender for Cloud to persons with specific RBAC roles on the subscription.
 * @property roles Defines which RBAC roles will get email notifications from Microsoft Defender for Cloud. List of allowed RBAC roles:
 * @property state Defines whether to send email notifications from AMicrosoft Defender for Cloud to persons with specific RBAC roles on the subscription.
 */
public data class SecurityContactPropertiesNotificationsByRoleArgs(
    public val roles: Output<List<Either<String, Roles>>>? = null,
    public val state: Output<Either<String, State>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.SecurityContactPropertiesNotificationsByRoleArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.SecurityContactPropertiesNotificationsByRoleArgs =
        com.pulumi.azurenative.security.inputs.SecurityContactPropertiesNotificationsByRoleArgs.builder()
            .roles(
                roles?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .state(
                state?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SecurityContactPropertiesNotificationsByRoleArgs].
 */
@PulumiTagMarker
public class SecurityContactPropertiesNotificationsByRoleArgsBuilder internal constructor() {
    private var roles: Output<List<Either<String, Roles>>>? = null

    private var state: Output<Either<String, State>>? = null

    /**
     * @param value Defines which RBAC roles will get email notifications from Microsoft Defender for Cloud. List of allowed RBAC roles:
     */
    @JvmName("giflemupyvrawyvv")
    public suspend fun roles(`value`: Output<List<Either<String, Roles>>>) {
        this.roles = value
    }

    @JvmName("cguuqluodldpypbf")
    public suspend fun roles(vararg values: Output<Either<String, Roles>>) {
        this.roles = Output.all(values.asList())
    }

    /**
     * @param values Defines which RBAC roles will get email notifications from Microsoft Defender for Cloud. List of allowed RBAC roles:
     */
    @JvmName("lpomjtrbdmfnoald")
    public suspend fun roles(values: List<Output<Either<String, Roles>>>) {
        this.roles = Output.all(values)
    }

    /**
     * @param value Defines whether to send email notifications from AMicrosoft Defender for Cloud to persons with specific RBAC roles on the subscription.
     */
    @JvmName("nhirqfmulktgtbki")
    public suspend fun state(`value`: Output<Either<String, State>>) {
        this.state = value
    }

    /**
     * @param value Defines which RBAC roles will get email notifications from Microsoft Defender for Cloud. List of allowed RBAC roles:
     */
    @JvmName("ahnxsibrxonxppqf")
    public suspend fun roles(`value`: List<Either<String, Roles>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param values Defines which RBAC roles will get email notifications from Microsoft Defender for Cloud. List of allowed RBAC roles:
     */
    @JvmName("hyvtdouykwetidxx")
    public suspend fun roles(vararg values: Either<String, Roles>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param value Defines whether to send email notifications from AMicrosoft Defender for Cloud to persons with specific RBAC roles on the subscription.
     */
    @JvmName("mrkibbdariuptltf")
    public suspend fun state(`value`: Either<String, State>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Defines whether to send email notifications from AMicrosoft Defender for Cloud to persons with specific RBAC roles on the subscription.
     */
    @JvmName("fwvkkdifibcrulrg")
    public fun state(`value`: String) {
        val toBeMapped = Either.ofLeft<String, State>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Defines whether to send email notifications from AMicrosoft Defender for Cloud to persons with specific RBAC roles on the subscription.
     */
    @JvmName("wcwmqmmfnstkdsvs")
    public fun state(`value`: State) {
        val toBeMapped = Either.ofRight<String, State>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    internal fun build(): SecurityContactPropertiesNotificationsByRoleArgs =
        SecurityContactPropertiesNotificationsByRoleArgs(
            roles = roles,
            state = state,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/SecurityContactPropertiesNotificationsByRoleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.SecurityContactPropertiesNotificationsByRoleArgs.builder
import com.pulumi.azurenative.security.kotlin.enums.Roles
import com.pulumi.azurenative.security.kotlin.enums.State
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines whether to send email notifications from Microsoft Defender for Cloud to persons with specific RBAC roles on the subscription.
 * @property roles Defines which RBAC roles will get email notifications from Microsoft Defender for Cloud. List of allowed RBAC roles:
 * @property state Defines whether to send email notifications from AMicrosoft Defender for Cloud to persons with specific RBAC roles on the subscription.
 */
public data class SecurityContactPropertiesNotificationsByRoleArgs(
    public val roles: Output<List<Either<String, Roles>>>? = null,
    public val state: Output<Either<String, State>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.SecurityContactPropertiesNotificationsByRoleArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.SecurityContactPropertiesNotificationsByRoleArgs =
        com.pulumi.azurenative.security.inputs.SecurityContactPropertiesNotificationsByRoleArgs.builder()
            .roles(
                roles?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .state(
                state?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SecurityContactPropertiesNotificationsByRoleArgs].
 */
@PulumiTagMarker
public class SecurityContactPropertiesNotificationsByRoleArgsBuilder internal constructor() {
    private var roles: Output<List<Either<String, Roles>>>? = null

    private var state: Output<Either<String, State>>? = null

    /**
     * @param value Defines which RBAC roles will get email notifications from Microsoft Defender for Cloud. List of allowed RBAC roles:
     */
    @JvmName("wdklmpoeliauygcu")
    public suspend fun roles(`value`: Output<List<Either<String, Roles>>>) {
        this.roles = value
    }

    @JvmName("olpmtplgddflnewa")
    public suspend fun roles(vararg values: Output<Either<String, Roles>>) {
        this.roles = Output.all(values.asList())
    }

    /**
     * @param values Defines which RBAC roles will get email notifications from Microsoft Defender for Cloud. List of allowed RBAC roles:
     */
    @JvmName("irghaxfdlbtbmlki")
    public suspend fun roles(values: List<Output<Either<String, Roles>>>) {
        this.roles = Output.all(values)
    }

    /**
     * @param value Defines whether to send email notifications from AMicrosoft Defender for Cloud to persons with specific RBAC roles on the subscription.
     */
    @JvmName("bgramnqoummpgbxh")
    public suspend fun state(`value`: Output<Either<String, State>>) {
        this.state = value
    }

    /**
     * @param value Defines which RBAC roles will get email notifications from Microsoft Defender for Cloud. List of allowed RBAC roles:
     */
    @JvmName("dmiuijmeldfrbirk")
    public suspend fun roles(`value`: List<Either<String, Roles>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param values Defines which RBAC roles will get email notifications from Microsoft Defender for Cloud. List of allowed RBAC roles:
     */
    @JvmName("nkxnvfaaqhiorqdt")
    public suspend fun roles(vararg values: Either<String, Roles>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param value Defines whether to send email notifications from AMicrosoft Defender for Cloud to persons with specific RBAC roles on the subscription.
     */
    @JvmName("qqvldomtcwctbjll")
    public suspend fun state(`value`: Either<String, State>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Defines whether to send email notifications from AMicrosoft Defender for Cloud to persons with specific RBAC roles on the subscription.
     */
    @JvmName("cnhavvrpismgyyqh")
    public fun state(`value`: String) {
        val toBeMapped = Either.ofLeft<String, State>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Defines whether to send email notifications from AMicrosoft Defender for Cloud to persons with specific RBAC roles on the subscription.
     */
    @JvmName("bsylbfcqwvugspvp")
    public fun state(`value`: State) {
        val toBeMapped = Either.ofRight<String, State>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    internal fun build(): SecurityContactPropertiesNotificationsByRoleArgs =
        SecurityContactPropertiesNotificationsByRoleArgs(
            roles = roles,
            state = state,
        )
}
